﻿# Export Advanced Configuration
[CmdletBinding()]
param($smComputerName="localhost")

#Create a connection to Service Manager that will be used by the rest of the script
New-SCManagementGroupConnection -ComputerName $smComputerName

$scriptPath = split-path -parent $MyInvocation.MyCommand.Definition
$exportDirPath = Join-Path $scriptPath "SvcCatExport"

$ErrorActionPreference = "Stop"


#Make sure export directory exists
$dirExists = Test-Path $exportDirPath
If (!$dirExists)
{
    $exportDir = New-Item -Path $exportDirPath -ItemType directory
}
else
{
    $exportDir = Get-Item -Path $exportDirPath
}

#Extract advanced configuration for all offerings in the MP
$offerings = get-scclass -name "System.RequestOffering"|Get-SCClassInstance

foreach($offering in $offerings)
{
    Write-Verbose "Processing $($offering.DisplayName)"
    $advConfig = (Get-SCRelationshipInstance -TargetInstance $offering |?{$_.RelationshipId -eq 'a7a5b110-8aaf-c03c-6391-99ff87921a2f'}).SourceObject #| format-Table SourceObject,TargetObject -au
    if($advConfig -ne $null)
    {
        Write-Verbose "Found Advanced Configuration for offering: $($offering.DisplayName), exporting..."
        [Xml]$Config = $advConfig.Values[1].Value
        $Config.Save("$(Join-Path -Path $exportDir.FullName -ChildPath $offering.Path).axml")
    }
}
Write-Verbose -Message "Done!"