﻿# Import Advanced Configurations
# Updated 12/6/2016 - No detects duplicate objects and remove those before import.
# Updated 12/14/2016 - Fixed bug where it incorrectly used "existingConfig" that was really marked for deletion.
[CmdletBinding()]
param(
    $smComputerName="localhost"
)

#Create a connection to Service Manager that will be used by the rest of the script
New-SCManagementGroupConnection -ComputerName $smComputerName
Write-Verbose -Message "***********************************************************"
$scriptPath = split-path -parent $MyInvocation.MyCommand.Definition
$exportDirPath = Join-Path $scriptPath "SvcCatExport"

$ErrorActionPreference = "Stop"

#Create advanced configuration instances
$advConfigClass = Get-SCClass -Name "WAP.RequestOffering.MetaData"
$configHasRO = Get-SCRelationship -Id 'a7a5b110-8aaf-c03c-6391-99ff87921a2f'
foreach($axml in (Get-ChildItem -Path $exportDirPath -Filter "*.axml"))
{
    #Get config
    [Xml]$xmlCfg = Get-Content $axml.FullName

    #Find target request offering
    $path = $axml.BaseName

    $ro = get-scclass -name "System.RequestOffering"|Get-SCClassInstance -Filter "Path -eq $($path)"
    if($ro -ne $null)
    {
        Write-Verbose -Message "Processing import data for Request Offering called: $($ro.DisplayName)"
        #Remove previous config.
        $existingConfig = Get-SCRelationshipInstance -TargetInstance $ro|?{$_.RelationshipId -eq "$($configHasRO.Id)" -and $_.SourceObject -ne $null}

        if($existingConfig -ne $null -and ($existingConfig.IsDeleted -or $existingConfig.GetType() -eq [Object[]]))
        {
            Write-Warning -Message "Cleaning up obsolete instances for "
            $existingConfig.SourceObject|Remove-SCClassInstance -Verbose
            $existingConfig = $null        
        }
    
        if($existingConfig -ne $null)
        {
            Write-Verbose -Message '---Updating existing advanced configuration based on import data.'
            $existingConfig.SourceObject[$advConfigClass, "Definition"].Value = "$($xmlCfg.OuterXml)"
            $existingConfig.SourceObject.Commit()
        }
        else
        {
            Write-Verbose -Message '---Creating new advanced configuration based in import data.'
            $proj = New-Object -TypeName "Microsoft.EnterpriseManagement.Common.EnterpriseManagementObjectProjection" -ArgumentList @($configHasRO.ManagementGroup,$advConfigClass)
            $proj.Object[$advConfigClass, "Id"].Value = "{0}"
            $proj.Object[$advConfigClass, "Definition"].Value = $xmlCfg.OuterXml
            $proj.Add($ro, $configHasRO.Target)  
            $proj.Commit()
        }
    Write-Verbose -Message "***********************************************************"
    }
    else
    {
        Write-Verbose -Message "Cannot find Request Offering in target system with BaseName: $($axml.BaseName)"
        Write-Verbose -Message "***********************************************************"
    }
}

Write-Verbose -Message "Done!"